@@ -9,4 +9,8 @@ if [ "$osrel" = "OpenBSD" ]; then
     rm dns.out.old
 fi
 
+mv dns.out dns.out.old
+grep -v "^libgcov profiling error:" dns.out.old > dns.out
+rm dns.out.old
+
 diff dns.out "$srcdir/dns.gold"
